TIMCallback class

Constructors

TIMCallback({Object? catchError, String? infoRecommendText, String? errorMsg, int? errorCode, StackTrace? stackTrace, int? infoCode, TIMCallbackType? type})

Properties

catchError ↔ Object?
getter/setter pair
errorCode ↔ int?
getter/setter pair
errorMsg ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoCode ↔ int?
getter/setter pair
infoRecommendText ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
getter/setter pair
type ↔ TIMCallbackType?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited